@@ -1,55 +1,121 @@
 var NAVTREEINDEX32 =
 {
+"d3/d7b/classisc_1_1dhcp_1_1Iface.html#a6c91bc85933abc2f6f6c2849c57b0464":[6,0,2,11,111,13],
+"d3/d7b/classisc_1_1dhcp_1_1Iface.html#a6d81ee7669f424956fc4e3782bee7f8f":[7,0,1,9,111,25],
+"d3/d7b/classisc_1_1dhcp_1_1Iface.html#a6d81ee7669f424956fc4e3782bee7f8f":[6,0,2,11,111,25],
+"d3/d7b/classisc_1_1dhcp_1_1Iface.html#a6f0800a023325d0fd7db184411d4cd1f":[6,0,2,11,111,35],
+"d3/d7b/classisc_1_1dhcp_1_1Iface.html#a6f0800a023325d0fd7db184411d4cd1f":[7,0,1,9,111,35],
+"d3/d7b/classisc_1_1dhcp_1_1Iface.html#a7154aa0891335f0aa74f6129690bc111":[7,0,1,9,111,11],
+"d3/d7b/classisc_1_1dhcp_1_1Iface.html#a7154aa0891335f0aa74f6129690bc111":[6,0,2,11,111,11],
+"d3/d7b/classisc_1_1dhcp_1_1Iface.html#a73bd6025f84409519784b68c0be30a73":[6,0,2,11,111,4],
+"d3/d7b/classisc_1_1dhcp_1_1Iface.html#a73bd6025f84409519784b68c0be30a73":[7,0,1,9,111,4],
+"d3/d7b/classisc_1_1dhcp_1_1Iface.html#a755463df5d30c59c70ccc7561c429a14":[7,0,1,9,111,21],
+"d3/d7b/classisc_1_1dhcp_1_1Iface.html#a755463df5d30c59c70ccc7561c429a14":[6,0,2,11,111,21],
+"d3/d7b/classisc_1_1dhcp_1_1Iface.html#a77bc46bc010a672dd2ba1e010211f7f0":[7,0,1,9,111,15],
+"d3/d7b/classisc_1_1dhcp_1_1Iface.html#a77bc46bc010a672dd2ba1e010211f7f0":[6,0,2,11,111,15],
+"d3/d7b/classisc_1_1dhcp_1_1Iface.html#a7cfa402aa892490dce7652793c455179":[7,0,1,9,111,31],
+"d3/d7b/classisc_1_1dhcp_1_1Iface.html#a7cfa402aa892490dce7652793c455179":[6,0,2,11,111,31],
+"d3/d7b/classisc_1_1dhcp_1_1Iface.html#a87028e7355d34b9b7348e2a6109f5072":[7,0,1,9,111,37],
+"d3/d7b/classisc_1_1dhcp_1_1Iface.html#a87028e7355d34b9b7348e2a6109f5072":[6,0,2,11,111,37],
+"d3/d7b/classisc_1_1dhcp_1_1Iface.html#a88d1b13e8f1f9ea73a30679eb0ac757e":[6,0,2,11,111,42],
+"d3/d7b/classisc_1_1dhcp_1_1Iface.html#a88d1b13e8f1f9ea73a30679eb0ac757e":[7,0,1,9,111,42],
+"d3/d7b/classisc_1_1dhcp_1_1Iface.html#a89b9f594a8965ec834ef3cd8ade23eb3":[6,0,2,11,111,32],
+"d3/d7b/classisc_1_1dhcp_1_1Iface.html#a89b9f594a8965ec834ef3cd8ade23eb3":[7,0,1,9,111,32],
+"d3/d7b/classisc_1_1dhcp_1_1Iface.html#a8c05e83eb5652c85a80aab1d724c5d49":[6,0,2,11,111,16],
+"d3/d7b/classisc_1_1dhcp_1_1Iface.html#a8c05e83eb5652c85a80aab1d724c5d49":[7,0,1,9,111,16],
+"d3/d7b/classisc_1_1dhcp_1_1Iface.html#a8f44699940932267e1cd1d2ed4e45e72":[6,0,2,11,111,1],
+"d3/d7b/classisc_1_1dhcp_1_1Iface.html#a8f44699940932267e1cd1d2ed4e45e72":[7,0,1,9,111,1],
+"d3/d7b/classisc_1_1dhcp_1_1Iface.html#a90f5f5f85807a3c5d9c49f5b34c843bc":[7,0,1,9,111,29],
+"d3/d7b/classisc_1_1dhcp_1_1Iface.html#a90f5f5f85807a3c5d9c49f5b34c843bc":[6,0,2,11,111,29],
+"d3/d7b/classisc_1_1dhcp_1_1Iface.html#a94168c3b1ea5b6329451e2354334f38e":[6,0,2,11,111,48],
+"d3/d7b/classisc_1_1dhcp_1_1Iface.html#a94168c3b1ea5b6329451e2354334f38e":[7,0,1,9,111,48],
+"d3/d7b/classisc_1_1dhcp_1_1Iface.html#a95c6e17e78c038896af0ae1bea9def90":[7,0,1,9,111,33],
+"d3/d7b/classisc_1_1dhcp_1_1Iface.html#a95c6e17e78c038896af0ae1bea9def90":[6,0,2,11,111,33],
+"d3/d7b/classisc_1_1dhcp_1_1Iface.html#a9c7711bc3411f367dc133659bb41ba49":[7,0,1,9,111,3],
+"d3/d7b/classisc_1_1dhcp_1_1Iface.html#a9c7711bc3411f367dc133659bb41ba49":[6,0,2,11,111,3],
+"d3/d7b/classisc_1_1dhcp_1_1Iface.html#aa9a845ef579c1f05ad89e159e455d86a":[7,0,1,9,111,40],
+"d3/d7b/classisc_1_1dhcp_1_1Iface.html#aa9a845ef579c1f05ad89e159e455d86a":[6,0,2,11,111,40],
+"d3/d7b/classisc_1_1dhcp_1_1Iface.html#ab49c85e00a35ac8e5cc27a874d9131dd":[7,0,1,9,111,9],
+"d3/d7b/classisc_1_1dhcp_1_1Iface.html#ab49c85e00a35ac8e5cc27a874d9131dd":[6,0,2,11,111,9],
+"d3/d7b/classisc_1_1dhcp_1_1Iface.html#ab9d324f789a8f7ad04494cd889ce56a9":[6,0,2,11,111,14],
+"d3/d7b/classisc_1_1dhcp_1_1Iface.html#ab9d324f789a8f7ad04494cd889ce56a9":[7,0,1,9,111,14],
+"d3/d7b/classisc_1_1dhcp_1_1Iface.html#ac6bdcbab6278265f3ba85ca57a1aa2f1":[6,0,2,11,111,49],
+"d3/d7b/classisc_1_1dhcp_1_1Iface.html#ac6bdcbab6278265f3ba85ca57a1aa2f1":[7,0,1,9,111,49],
+"d3/d7b/classisc_1_1dhcp_1_1Iface.html#ace5222379af60deeb063149bf76c0335":[7,0,1,9,111,0],
+"d3/d7b/classisc_1_1dhcp_1_1Iface.html#ace5222379af60deeb063149bf76c0335":[6,0,2,11,111,0],
+"d3/d7b/classisc_1_1dhcp_1_1Iface.html#ad10cc29ebf7912fc742f02f6cc6c9710":[6,0,2,11,111,6],
+"d3/d7b/classisc_1_1dhcp_1_1Iface.html#ad10cc29ebf7912fc742f02f6cc6c9710":[7,0,1,9,111,6],
+"d3/d7b/classisc_1_1dhcp_1_1Iface.html#ad50c8f16d45ce7d5d0c530bfb4415d48":[7,0,1,9,111,12],
+"d3/d7b/classisc_1_1dhcp_1_1Iface.html#ad50c8f16d45ce7d5d0c530bfb4415d48":[6,0,2,11,111,12],
+"d3/d7b/classisc_1_1dhcp_1_1Iface.html#ad5e9c8174b84e44f480e43a4e3e23177":[6,0,2,11,111,8],
+"d3/d7b/classisc_1_1dhcp_1_1Iface.html#ad5e9c8174b84e44f480e43a4e3e23177":[7,0,1,9,111,8],
+"d3/d7b/classisc_1_1dhcp_1_1Iface.html#ad614f8ce2cecefcc8c18a4718228012e":[6,0,2,11,111,46],
+"d3/d7b/classisc_1_1dhcp_1_1Iface.html#ad614f8ce2cecefcc8c18a4718228012e":[7,0,1,9,111,46],
+"d3/d7b/classisc_1_1dhcp_1_1Iface.html#ad97fd428a811e1f2d4f81c5ae805965d":[6,0,2,11,111,43],
+"d3/d7b/classisc_1_1dhcp_1_1Iface.html#ad97fd428a811e1f2d4f81c5ae805965d":[7,0,1,9,111,43],
+"d3/d7b/classisc_1_1dhcp_1_1Iface.html#aebb6caff1572be8ba33b61a88652dbad":[6,0,2,11,111,39],
+"d3/d7b/classisc_1_1dhcp_1_1Iface.html#aebb6caff1572be8ba33b61a88652dbad":[7,0,1,9,111,39],
+"d3/d7b/classisc_1_1dhcp_1_1Iface.html#aebc9de0f2c66f4f6c489d174fa9b670c":[7,0,1,9,111,36],
+"d3/d7b/classisc_1_1dhcp_1_1Iface.html#aebc9de0f2c66f4f6c489d174fa9b670c":[6,0,2,11,111,36],
+"d3/d7b/classisc_1_1dhcp_1_1Iface.html#aee7e306d358f3aafd614264bed4118bc":[7,0,1,9,111,23],
+"d3/d7b/classisc_1_1dhcp_1_1Iface.html#aee7e306d358f3aafd614264bed4118bc":[6,0,2,11,111,23],
+"d3/d7b/classisc_1_1dhcp_1_1Iface.html#af6082f07a343044c8affdd891be70a93":[7,0,1,9,111,53],
+"d3/d7b/classisc_1_1dhcp_1_1Iface.html#af6082f07a343044c8affdd891be70a93":[6,0,2,11,111,53],
+"d3/d7b/classisc_1_1dhcp_1_1Iface.html#afeb85329cde32e5b5e7c7400c038bf1e":[6,0,2,11,111,17],
+"d3/d7b/classisc_1_1dhcp_1_1Iface.html#afeb85329cde32e5b5e7c7400c038bf1e":[7,0,1,9,111,17],
+"d3/d7b/srv__config_8cc.html":[8,0,0,2,11,140],
+"d3/d7b/srv__config_8cc_source.html":[8,0,0,2,11,140],
+"d3/d7f/d2__zone_8cc.html":[8,0,0,2,7,16],
 "d3/d7f/d2__zone_8cc.html#a8678449cc0bbd55e9cd1965f1ee7b441":[8,0,0,2,7,16,0],
 "d3/d7f/d2__zone_8cc_source.html":[8,0,0,2,7,16],
 "d3/d7f/structisc_1_1ha_1_1CommunicationState4_1_1ConnectingClient4.html":[6,0,2,16,2,0],
 "d3/d7f/structisc_1_1ha_1_1CommunicationState4_1_1ConnectingClient4.html":[7,0,1,14,2,0],
-"d3/d7f/structisc_1_1ha_1_1CommunicationState4_1_1ConnectingClient4.html#a03c799cb9f91998979783f10edffe6ba":[6,0,2,16,2,0,0],
 "d3/d7f/structisc_1_1ha_1_1CommunicationState4_1_1ConnectingClient4.html#a03c799cb9f91998979783f10edffe6ba":[7,0,1,14,2,0,0],
+"d3/d7f/structisc_1_1ha_1_1CommunicationState4_1_1ConnectingClient4.html#a03c799cb9f91998979783f10edffe6ba":[6,0,2,16,2,0,0],
 "d3/d7f/structisc_1_1ha_1_1CommunicationState4_1_1ConnectingClient4.html#a980ae92043ce04669670cab4d406483a":[6,0,2,16,2,0,1],
 "d3/d7f/structisc_1_1ha_1_1CommunicationState4_1_1ConnectingClient4.html#a980ae92043ce04669670cab4d406483a":[7,0,1,14,2,0,1],
-"d3/d7f/structisc_1_1ha_1_1CommunicationState4_1_1ConnectingClient4.html#a9d38559c22fbefbed6c8af55d8c771c2":[6,0,2,16,2,0,2],
 "d3/d7f/structisc_1_1ha_1_1CommunicationState4_1_1ConnectingClient4.html#a9d38559c22fbefbed6c8af55d8c771c2":[7,0,1,14,2,0,2],
+"d3/d7f/structisc_1_1ha_1_1CommunicationState4_1_1ConnectingClient4.html#a9d38559c22fbefbed6c8af55d8c771c2":[6,0,2,16,2,0,2],
 "d3/d81/classisc_1_1dns_1_1rdata_1_1generic_1_1NAPTR.html":[7,0,1,11,1,2,13],
 "d3/d81/classisc_1_1dns_1_1rdata_1_1generic_1_1NAPTR.html":[6,0,2,13,2,2,13],
-"d3/d81/classisc_1_1dns_1_1rdata_1_1generic_1_1NAPTR.html#a014cb1426c2aae457f34114af0bdc417":[6,0,2,13,2,2,13,12],
 "d3/d81/classisc_1_1dns_1_1rdata_1_1generic_1_1NAPTR.html#a014cb1426c2aae457f34114af0bdc417":[7,0,1,11,1,2,13,12],
+"d3/d81/classisc_1_1dns_1_1rdata_1_1generic_1_1NAPTR.html#a014cb1426c2aae457f34114af0bdc417":[6,0,2,13,2,2,13,12],
 "d3/d81/classisc_1_1dns_1_1rdata_1_1generic_1_1NAPTR.html#a1fb6b9f1887442a39060f35a4eb13e59":[7,0,1,11,1,2,13,10],
 "d3/d81/classisc_1_1dns_1_1rdata_1_1generic_1_1NAPTR.html#a1fb6b9f1887442a39060f35a4eb13e59":[6,0,2,13,2,2,13,10],
 "d3/d81/classisc_1_1dns_1_1rdata_1_1generic_1_1NAPTR.html#a20323a51a01016cc29c32700d494249d":[7,0,1,11,1,2,13,7],
 "d3/d81/classisc_1_1dns_1_1rdata_1_1generic_1_1NAPTR.html#a20323a51a01016cc29c32700d494249d":[6,0,2,13,2,2,13,7],
-"d3/d81/classisc_1_1dns_1_1rdata_1_1generic_1_1NAPTR.html#a2f86bdb8b0da28d8fb566bf30c1e06a0":[6,0,2,13,2,2,13,5],
 "d3/d81/classisc_1_1dns_1_1rdata_1_1generic_1_1NAPTR.html#a2f86bdb8b0da28d8fb566bf30c1e06a0":[7,0,1,11,1,2,13,5],
+"d3/d81/classisc_1_1dns_1_1rdata_1_1generic_1_1NAPTR.html#a2f86bdb8b0da28d8fb566bf30c1e06a0":[6,0,2,13,2,2,13,5],
 "d3/d81/classisc_1_1dns_1_1rdata_1_1generic_1_1NAPTR.html#a3ac67e7d94efb19e721f3e6403d85e86":[7,0,1,11,1,2,13,14],
 "d3/d81/classisc_1_1dns_1_1rdata_1_1generic_1_1NAPTR.html#a3ac67e7d94efb19e721f3e6403d85e86":[6,0,2,13,2,2,13,14],
-"d3/d81/classisc_1_1dns_1_1rdata_1_1generic_1_1NAPTR.html#a4e5d1a231e68c3f684efb7e5317646de":[6,0,2,13,2,2,13,0],
 "d3/d81/classisc_1_1dns_1_1rdata_1_1generic_1_1NAPTR.html#a4e5d1a231e68c3f684efb7e5317646de":[7,0,1,11,1,2,13,0],
-"d3/d81/classisc_1_1dns_1_1rdata_1_1generic_1_1NAPTR.html#a53022ec288745b30a334d15eedb2a542":[6,0,2,13,2,2,13,6],
+"d3/d81/classisc_1_1dns_1_1rdata_1_1generic_1_1NAPTR.html#a4e5d1a231e68c3f684efb7e5317646de":[6,0,2,13,2,2,13,0],
 "d3/d81/classisc_1_1dns_1_1rdata_1_1generic_1_1NAPTR.html#a53022ec288745b30a334d15eedb2a542":[7,0,1,11,1,2,13,6],
-"d3/d81/classisc_1_1dns_1_1rdata_1_1generic_1_1NAPTR.html#a6612682afe4c21ea647cbe4c88de1171":[7,0,1,11,1,2,13,13],
+"d3/d81/classisc_1_1dns_1_1rdata_1_1generic_1_1NAPTR.html#a53022ec288745b30a334d15eedb2a542":[6,0,2,13,2,2,13,6],
 "d3/d81/classisc_1_1dns_1_1rdata_1_1generic_1_1NAPTR.html#a6612682afe4c21ea647cbe4c88de1171":[6,0,2,13,2,2,13,13],
-"d3/d81/classisc_1_1dns_1_1rdata_1_1generic_1_1NAPTR.html#a7c6feccc08c6bed9710734f8df24b4e0":[7,0,1,11,1,2,13,1],
+"d3/d81/classisc_1_1dns_1_1rdata_1_1generic_1_1NAPTR.html#a6612682afe4c21ea647cbe4c88de1171":[7,0,1,11,1,2,13,13],
 "d3/d81/classisc_1_1dns_1_1rdata_1_1generic_1_1NAPTR.html#a7c6feccc08c6bed9710734f8df24b4e0":[6,0,2,13,2,2,13,1],
-"d3/d81/classisc_1_1dns_1_1rdata_1_1generic_1_1NAPTR.html#a808214dab7b241c7ab0c01b3f4bc5825":[7,0,1,11,1,2,13,11],
+"d3/d81/classisc_1_1dns_1_1rdata_1_1generic_1_1NAPTR.html#a7c6feccc08c6bed9710734f8df24b4e0":[7,0,1,11,1,2,13,1],
 "d3/d81/classisc_1_1dns_1_1rdata_1_1generic_1_1NAPTR.html#a808214dab7b241c7ab0c01b3f4bc5825":[6,0,2,13,2,2,13,11],
+"d3/d81/classisc_1_1dns_1_1rdata_1_1generic_1_1NAPTR.html#a808214dab7b241c7ab0c01b3f4bc5825":[7,0,1,11,1,2,13,11],
 "d3/d81/classisc_1_1dns_1_1rdata_1_1generic_1_1NAPTR.html#ac08621c575ab39f9341701168b0d4592":[7,0,1,11,1,2,13,4],
 "d3/d81/classisc_1_1dns_1_1rdata_1_1generic_1_1NAPTR.html#ac08621c575ab39f9341701168b0d4592":[6,0,2,13,2,2,13,4],
 "d3/d81/classisc_1_1dns_1_1rdata_1_1generic_1_1NAPTR.html#aca59c0174e9311258eb1969f73c38e78":[6,0,2,13,2,2,13,9],
 "d3/d81/classisc_1_1dns_1_1rdata_1_1generic_1_1NAPTR.html#aca59c0174e9311258eb1969f73c38e78":[7,0,1,11,1,2,13,9],
-"d3/d81/classisc_1_1dns_1_1rdata_1_1generic_1_1NAPTR.html#ad600e16d90cc6cc66b1a4be36620cd17":[7,0,1,11,1,2,13,15],
 "d3/d81/classisc_1_1dns_1_1rdata_1_1generic_1_1NAPTR.html#ad600e16d90cc6cc66b1a4be36620cd17":[6,0,2,13,2,2,13,15],
-"d3/d81/classisc_1_1dns_1_1rdata_1_1generic_1_1NAPTR.html#ada2f7e0bd8ad978e68002547771a8d41":[7,0,1,11,1,2,13,2],
+"d3/d81/classisc_1_1dns_1_1rdata_1_1generic_1_1NAPTR.html#ad600e16d90cc6cc66b1a4be36620cd17":[7,0,1,11,1,2,13,15],
 "d3/d81/classisc_1_1dns_1_1rdata_1_1generic_1_1NAPTR.html#ada2f7e0bd8ad978e68002547771a8d41":[6,0,2,13,2,2,13,2],
+"d3/d81/classisc_1_1dns_1_1rdata_1_1generic_1_1NAPTR.html#ada2f7e0bd8ad978e68002547771a8d41":[7,0,1,11,1,2,13,2],
 "d3/d81/classisc_1_1dns_1_1rdata_1_1generic_1_1NAPTR.html#ae580d71106364afee8aa5ff140302301":[7,0,1,11,1,2,13,8],
 "d3/d81/classisc_1_1dns_1_1rdata_1_1generic_1_1NAPTR.html#ae580d71106364afee8aa5ff140302301":[6,0,2,13,2,2,13,8],
-"d3/d81/classisc_1_1dns_1_1rdata_1_1generic_1_1NAPTR.html#affbbfef36d0df365aefd0e8277f5bfbb":[6,0,2,13,2,2,13,3],
 "d3/d81/classisc_1_1dns_1_1rdata_1_1generic_1_1NAPTR.html#affbbfef36d0df365aefd0e8277f5bfbb":[7,0,1,11,1,2,13,3],
+"d3/d81/classisc_1_1dns_1_1rdata_1_1generic_1_1NAPTR.html#affbbfef36d0df365aefd0e8277f5bfbb":[6,0,2,13,2,2,13,3],
 "d3/d83/adaptor__pool_8h.html":[8,0,0,2,24,9],
 "d3/d83/adaptor__pool_8h_source.html":[8,0,0,2,24,9],
 "d3/d84/sanity__checks__parser_8h.html":[8,0,0,2,11,0,22],
 "d3/d84/sanity__checks__parser_8h_source.html":[8,0,0,2,11,0,22],
-"d3/d85/classisc_1_1d2_1_1D2SimpleParser.html":[7,0,1,6,15],
 "d3/d85/classisc_1_1d2_1_1D2SimpleParser.html":[6,0,2,7,15],
+"d3/d85/classisc_1_1d2_1_1D2SimpleParser.html":[7,0,1,6,15],
 "d3/d85/classisc_1_1d2_1_1D2SimpleParser.html#a79a2126f2949bf20828c25510e0bc074":[6,0,2,7,15,0],
 "d3/d85/classisc_1_1d2_1_1D2SimpleParser.html#a79a2126f2949bf20828c25510e0bc074":[7,0,1,6,15,0],
 "d3/d86/lease_8cc.html":[8,0,0,2,11,105],
@@ -62,47 +128,47 @@ var NAVTREEINDEX32 =
 "d3/d89/mysql__connection_8h_source.html":[8,0,0,2,18,3],
 "d3/d8a/packet__queue__mgr_8h.html":[8,0,0,2,9,63],
 "d3/d8a/packet__queue__mgr_8h_source.html":[8,0,0,2,9,63],
-"d3/d8c/classisc_1_1asiolink_1_1UDPEndpoint.html":[7,0,1,2,30],
 "d3/d8c/classisc_1_1asiolink_1_1UDPEndpoint.html":[6,0,2,2,30],
-"d3/d8c/classisc_1_1asiolink_1_1UDPEndpoint.html#a0f2056884bebe5860131ae51f785571e":[6,0,2,2,30,9],
+"d3/d8c/classisc_1_1asiolink_1_1UDPEndpoint.html":[7,0,1,2,30],
 "d3/d8c/classisc_1_1asiolink_1_1UDPEndpoint.html#a0f2056884bebe5860131ae51f785571e":[7,0,1,2,30,9],
+"d3/d8c/classisc_1_1asiolink_1_1UDPEndpoint.html#a0f2056884bebe5860131ae51f785571e":[6,0,2,2,30,9],
 "d3/d8c/classisc_1_1asiolink_1_1UDPEndpoint.html#a35529e3cf18c457ff158122cc5c8a37c":[7,0,1,2,30,8],
 "d3/d8c/classisc_1_1asiolink_1_1UDPEndpoint.html#a35529e3cf18c457ff158122cc5c8a37c":[6,0,2,2,30,8],
-"d3/d8c/classisc_1_1asiolink_1_1UDPEndpoint.html#a4723edb911cdcca4fe84f4db1f5ca197":[6,0,2,2,30,11],
 "d3/d8c/classisc_1_1asiolink_1_1UDPEndpoint.html#a4723edb911cdcca4fe84f4db1f5ca197":[7,0,1,2,30,11],
+"d3/d8c/classisc_1_1asiolink_1_1UDPEndpoint.html#a4723edb911cdcca4fe84f4db1f5ca197":[6,0,2,2,30,11],
 "d3/d8c/classisc_1_1asiolink_1_1UDPEndpoint.html#a4bca808d03b5cc158725918a0f8d4d9b":[6,0,2,2,30,4],
 "d3/d8c/classisc_1_1asiolink_1_1UDPEndpoint.html#a4bca808d03b5cc158725918a0f8d4d9b":[7,0,1,2,30,4],
 "d3/d8c/classisc_1_1asiolink_1_1UDPEndpoint.html#a79fe5963930c8b41e6900589000ad5f0":[6,0,2,2,30,3],
 "d3/d8c/classisc_1_1asiolink_1_1UDPEndpoint.html#a79fe5963930c8b41e6900589000ad5f0":[7,0,1,2,30,3],
-"d3/d8c/classisc_1_1asiolink_1_1UDPEndpoint.html#a7fa505fa6eb608fbd3d4e0334ac17ac5":[7,0,1,2,30,0],
 "d3/d8c/classisc_1_1asiolink_1_1UDPEndpoint.html#a7fa505fa6eb608fbd3d4e0334ac17ac5":[6,0,2,2,30,0],
-"d3/d8c/classisc_1_1asiolink_1_1UDPEndpoint.html#a97bd5e98e50831c7beb567a28c04589f":[6,0,2,2,30,10],
+"d3/d8c/classisc_1_1asiolink_1_1UDPEndpoint.html#a7fa505fa6eb608fbd3d4e0334ac17ac5":[7,0,1,2,30,0],
 "d3/d8c/classisc_1_1asiolink_1_1UDPEndpoint.html#a97bd5e98e50831c7beb567a28c04589f":[7,0,1,2,30,10],
-"d3/d8c/classisc_1_1asiolink_1_1UDPEndpoint.html#aa6a46e9b44d8bd2555accf37f7448884":[7,0,1,2,30,5],
+"d3/d8c/classisc_1_1asiolink_1_1UDPEndpoint.html#a97bd5e98e50831c7beb567a28c04589f":[6,0,2,2,30,10],
 "d3/d8c/classisc_1_1asiolink_1_1UDPEndpoint.html#aa6a46e9b44d8bd2555accf37f7448884":[6,0,2,2,30,5],
-"d3/d8c/classisc_1_1asiolink_1_1UDPEndpoint.html#ab471e178909300cfe8ffcdfa0dcabac2":[6,0,2,2,30,2],
+"d3/d8c/classisc_1_1asiolink_1_1UDPEndpoint.html#aa6a46e9b44d8bd2555accf37f7448884":[7,0,1,2,30,5],
 "d3/d8c/classisc_1_1asiolink_1_1UDPEndpoint.html#ab471e178909300cfe8ffcdfa0dcabac2":[7,0,1,2,30,2],
+"d3/d8c/classisc_1_1asiolink_1_1UDPEndpoint.html#ab471e178909300cfe8ffcdfa0dcabac2":[6,0,2,2,30,2],
 "d3/d8c/classisc_1_1asiolink_1_1UDPEndpoint.html#ace7bb4c16233cad80916e6d9bfddeb61":[6,0,2,2,30,1],
 "d3/d8c/classisc_1_1asiolink_1_1UDPEndpoint.html#ace7bb4c16233cad80916e6d9bfddeb61":[7,0,1,2,30,1],
-"d3/d8c/classisc_1_1asiolink_1_1UDPEndpoint.html#aea77e034869719b72a00b3298e2fcf16":[6,0,2,2,30,7],
 "d3/d8c/classisc_1_1asiolink_1_1UDPEndpoint.html#aea77e034869719b72a00b3298e2fcf16":[7,0,1,2,30,7],
+"d3/d8c/classisc_1_1asiolink_1_1UDPEndpoint.html#aea77e034869719b72a00b3298e2fcf16":[6,0,2,2,30,7],
 "d3/d8c/classisc_1_1asiolink_1_1UDPEndpoint.html#af7404ea9183ab6c0c1d2ecc59c0965f2":[6,0,2,2,30,6],
 "d3/d8c/classisc_1_1asiolink_1_1UDPEndpoint.html#af7404ea9183ab6c0c1d2ecc59c0965f2":[7,0,1,2,30,6],
-"d3/d8e/classisc_1_1dhcp_1_1MySqlHostDataSource_1_1MySqlHostContextAlloc.html":[6,0,2,11,155,0],
 "d3/d8e/classisc_1_1dhcp_1_1MySqlHostDataSource_1_1MySqlHostContextAlloc.html":[7,0,1,9,155,0],
+"d3/d8e/classisc_1_1dhcp_1_1MySqlHostDataSource_1_1MySqlHostContextAlloc.html":[6,0,2,11,155,0],
 "d3/d8e/classisc_1_1dhcp_1_1MySqlHostDataSource_1_1MySqlHostContextAlloc.html#a8dc2ba68d51c5ba73d3b76ff6ba6285b":[7,0,1,9,155,0,0],
 "d3/d8e/classisc_1_1dhcp_1_1MySqlHostDataSource_1_1MySqlHostContextAlloc.html#a8dc2ba68d51c5ba73d3b76ff6ba6285b":[6,0,2,11,155,0,0],
-"d3/d8e/classisc_1_1dhcp_1_1MySqlHostDataSource_1_1MySqlHostContextAlloc.html#ab98e72e0c4cb51efa21a09b7b614e333":[6,0,2,11,155,0,2],
 "d3/d8e/classisc_1_1dhcp_1_1MySqlHostDataSource_1_1MySqlHostContextAlloc.html#ab98e72e0c4cb51efa21a09b7b614e333":[7,0,1,9,155,0,2],
+"d3/d8e/classisc_1_1dhcp_1_1MySqlHostDataSource_1_1MySqlHostContextAlloc.html#ab98e72e0c4cb51efa21a09b7b614e333":[6,0,2,11,155,0,2],
 "d3/d8e/classisc_1_1dhcp_1_1MySqlHostDataSource_1_1MySqlHostContextAlloc.html#abae8d6c4892a81a6cab95869337366dc":[7,0,1,9,155,0,1],
 "d3/d8e/classisc_1_1dhcp_1_1MySqlHostDataSource_1_1MySqlHostContextAlloc.html#abae8d6c4892a81a6cab95869337366dc":[6,0,2,11,155,0,1],
 "d3/d8e/lfc__log_8cc.html":[8,0,0,0,4,2],
 "d3/d8e/lfc__log_8cc.html#acd81d2d7e9e13e883c1b4133fb32a7c8":[8,0,0,0,4,2,0],
 "d3/d8e/lfc__log_8cc_source.html":[8,0,0,0,4,2],
-"d3/d92/classisc_1_1dhcp_1_1DUID.html":[6,0,2,11,78],
 "d3/d92/classisc_1_1dhcp_1_1DUID.html":[7,0,1,9,78],
-"d3/d92/classisc_1_1dhcp_1_1DUID.html#a15487d5b9fd2041206bd49df33f3f72b":[7,0,1,9,78,5],
+"d3/d92/classisc_1_1dhcp_1_1DUID.html":[6,0,2,11,78],
 "d3/d92/classisc_1_1dhcp_1_1DUID.html#a15487d5b9fd2041206bd49df33f3f72b":[6,0,2,11,78,5],
+"d3/d92/classisc_1_1dhcp_1_1DUID.html#a15487d5b9fd2041206bd49df33f3f72b":[7,0,1,9,78,5],
 "d3/d92/classisc_1_1dhcp_1_1DUID.html#a3fd952b326230eba90e603074cbaba8d":[6,0,2,11,78,2],
 "d3/d92/classisc_1_1dhcp_1_1DUID.html#a3fd952b326230eba90e603074cbaba8d":[7,0,1,9,78,2],
 "d3/d92/classisc_1_1dhcp_1_1DUID.html#a4c94695c99aec3fee96ff41276704add":[6,0,2,11,78,6],
@@ -111,24 +177,24 @@ var NAVTREEINDEX32 =
 "d3/d92/classisc_1_1dhcp_1_1DUID.html#a52116eea8cbd5736d0878e475815df6d":[7,0,1,9,78,7],
 "d3/d92/classisc_1_1dhcp_1_1DUID.html#a6ff1959c65690c36808e141b043777cb":[6,0,2,11,78,1],
 "d3/d92/classisc_1_1dhcp_1_1DUID.html#a6ff1959c65690c36808e141b043777cb":[7,0,1,9,78,1],
-"d3/d92/classisc_1_1dhcp_1_1DUID.html#ac1bcc06d8e196eedc3f1a43f18ff1d47":[7,0,1,9,78,8],
 "d3/d92/classisc_1_1dhcp_1_1DUID.html#ac1bcc06d8e196eedc3f1a43f18ff1d47":[6,0,2,11,78,8],
+"d3/d92/classisc_1_1dhcp_1_1DUID.html#ac1bcc06d8e196eedc3f1a43f18ff1d47":[7,0,1,9,78,8],
 "d3/d92/classisc_1_1dhcp_1_1DUID.html#adbe04141f4d8013a01effadda9c97c50":[6,0,2,11,78,0],
 "d3/d92/classisc_1_1dhcp_1_1DUID.html#adbe04141f4d8013a01effadda9c97c50":[7,0,1,9,78,0],
-"d3/d92/classisc_1_1dhcp_1_1DUID.html#adbe04141f4d8013a01effadda9c97c50a16c50595a1a2eb96e71c460107b43366":[6,0,2,11,78,0,3],
 "d3/d92/classisc_1_1dhcp_1_1DUID.html#adbe04141f4d8013a01effadda9c97c50a16c50595a1a2eb96e71c460107b43366":[7,0,1,9,78,0,3],
-"d3/d92/classisc_1_1dhcp_1_1DUID.html#adbe04141f4d8013a01effadda9c97c50a336b8a356e2ea23a0855e471c6612411":[6,0,2,11,78,0,1],
+"d3/d92/classisc_1_1dhcp_1_1DUID.html#adbe04141f4d8013a01effadda9c97c50a16c50595a1a2eb96e71c460107b43366":[6,0,2,11,78,0,3],
 "d3/d92/classisc_1_1dhcp_1_1DUID.html#adbe04141f4d8013a01effadda9c97c50a336b8a356e2ea23a0855e471c6612411":[7,0,1,9,78,0,1],
-"d3/d92/classisc_1_1dhcp_1_1DUID.html#adbe04141f4d8013a01effadda9c97c50acea738daca70f070501d426e76c87b73":[6,0,2,11,78,0,5],
+"d3/d92/classisc_1_1dhcp_1_1DUID.html#adbe04141f4d8013a01effadda9c97c50a336b8a356e2ea23a0855e471c6612411":[6,0,2,11,78,0,1],
 "d3/d92/classisc_1_1dhcp_1_1DUID.html#adbe04141f4d8013a01effadda9c97c50acea738daca70f070501d426e76c87b73":[7,0,1,9,78,0,5],
+"d3/d92/classisc_1_1dhcp_1_1DUID.html#adbe04141f4d8013a01effadda9c97c50acea738daca70f070501d426e76c87b73":[6,0,2,11,78,0,5],
 "d3/d92/classisc_1_1dhcp_1_1DUID.html#adbe04141f4d8013a01effadda9c97c50ad82e53106f45f3926b4142dc402c11e8":[7,0,1,9,78,0,0],
 "d3/d92/classisc_1_1dhcp_1_1DUID.html#adbe04141f4d8013a01effadda9c97c50ad82e53106f45f3926b4142dc402c11e8":[6,0,2,11,78,0,0],
-"d3/d92/classisc_1_1dhcp_1_1DUID.html#adbe04141f4d8013a01effadda9c97c50ad8860466ab7048d3663a069e31170d4b":[6,0,2,11,78,0,2],
 "d3/d92/classisc_1_1dhcp_1_1DUID.html#adbe04141f4d8013a01effadda9c97c50ad8860466ab7048d3663a069e31170d4b":[7,0,1,9,78,0,2],
+"d3/d92/classisc_1_1dhcp_1_1DUID.html#adbe04141f4d8013a01effadda9c97c50ad8860466ab7048d3663a069e31170d4b":[6,0,2,11,78,0,2],
 "d3/d92/classisc_1_1dhcp_1_1DUID.html#adbe04141f4d8013a01effadda9c97c50af7f33513c9b6ac9ca4586439cd5c026d":[7,0,1,9,78,0,4],
 "d3/d92/classisc_1_1dhcp_1_1DUID.html#adbe04141f4d8013a01effadda9c97c50af7f33513c9b6ac9ca4586439cd5c026d":[6,0,2,11,78,0,4],
-"d3/d92/classisc_1_1dhcp_1_1DUID.html#aebaa7a59dc9be131f1e9ede9bb0f1017":[6,0,2,11,78,3],
 "d3/d92/classisc_1_1dhcp_1_1DUID.html#aebaa7a59dc9be131f1e9ede9bb0f1017":[7,0,1,9,78,3],
+"d3/d92/classisc_1_1dhcp_1_1DUID.html#aebaa7a59dc9be131f1e9ede9bb0f1017":[6,0,2,11,78,3],
 "d3/d92/classisc_1_1dhcp_1_1DUID.html#af4df859d0bcb75b7adc36b5170ac4f9c":[7,0,1,9,78,4],
 "d3/d92/classisc_1_1dhcp_1_1DUID.html#af4df859d0bcb75b7adc36b5170ac4f9c":[6,0,2,11,78,4],
 "d3/d96/classisc_1_1dhcp_1_1PoolsListParser.html":[7,0,1,9,263],
@@ -137,117 +203,51 @@ var NAVTREEINDEX32 =
 "d3/d96/classisc_1_1dhcp_1_1PoolsListParser.html#a1f0ff1e155b24a4b73d4433691dc49f1":[7,0,1,9,263,2],
 "d3/d96/classisc_1_1dhcp_1_1PoolsListParser.html#a2de9c0c942605298bc19098bca031851":[6,0,2,11,263,1],
 "d3/d96/classisc_1_1dhcp_1_1PoolsListParser.html#a2de9c0c942605298bc19098bca031851":[7,0,1,9,263,1],
-"d3/d96/classisc_1_1dhcp_1_1PoolsListParser.html#af817970cccf3e0cf67bc93a33cacaca5":[6,0,2,11,263,0],
 "d3/d96/classisc_1_1dhcp_1_1PoolsListParser.html#af817970cccf3e0cf67bc93a33cacaca5":[7,0,1,9,263,0],
+"d3/d96/classisc_1_1dhcp_1_1PoolsListParser.html#af817970cccf3e0cf67bc93a33cacaca5":[6,0,2,11,263,0],
+"d3/d96/libdhcp_ha.html":[0,17],
+"d3/d96/libdhcp_ha.html#haAyncCommunication":[0,17,3],
+"d3/d96/libdhcp_ha.html#haClientClassification":[0,17,4],
+"d3/d96/libdhcp_ha.html#haCodeStructure":[0,17,5],
+"d3/d96/libdhcp_ha.html#haCommandCreator":[0,17,5,4],
+"d3/d96/libdhcp_ha.html#haCommunicationState":[0,17,5,3],
+"d3/d96/libdhcp_ha.html#haImplementation":[0,17,5,1],
+"d3/d96/libdhcp_ha.html#haMTCompatibility":[0,17,7],
+"d3/d96/libdhcp_ha.html#haNameUpdates":[0,17,6,1],
+"d3/d96/libdhcp_ha.html#haNotableDifferences":[0,17,2],
+"d3/d96/libdhcp_ha.html#haOverview":[0,17,0],
+"d3/d96/libdhcp_ha.html#haQueryFilter":[0,17,5,2],
+"d3/d96/libdhcp_ha.html#haService":[0,17,5,0],
+"d3/d96/libdhcp_ha.html#haShortcomings":[0,17,6],
+"d3/d96/libdhcp_ha.html#haStateMachineControl":[0,17,6,0],
+"d3/d96/libdhcp_ha.html#haWhyHookLibrary":[0,17,1],
 "d3/d97/classisc_1_1dhcp_1_1TokenVendorClass.html":[6,0,2,11,349],
 "d3/d97/classisc_1_1dhcp_1_1TokenVendorClass.html":[7,0,1,9,349],
-"d3/d97/classisc_1_1dhcp_1_1TokenVendorClass.html#a24208103fbe846c4ebc5684603b2ad3f":[6,0,2,11,349,0],
 "d3/d97/classisc_1_1dhcp_1_1TokenVendorClass.html#a24208103fbe846c4ebc5684603b2ad3f":[7,0,1,9,349,0],
+"d3/d97/classisc_1_1dhcp_1_1TokenVendorClass.html#a24208103fbe846c4ebc5684603b2ad3f":[6,0,2,11,349,0],
 "d3/d97/classisc_1_1dhcp_1_1TokenVendorClass.html#a2537e0f8dd8f7502c44af07c771a93f0":[6,0,2,11,349,3],
 "d3/d97/classisc_1_1dhcp_1_1TokenVendorClass.html#a2537e0f8dd8f7502c44af07c771a93f0":[7,0,1,9,349,3],
-"d3/d97/classisc_1_1dhcp_1_1TokenVendorClass.html#a2b46f0e12422f2d810dd782e2530613b":[7,0,1,9,349,1],
 "d3/d97/classisc_1_1dhcp_1_1TokenVendorClass.html#a2b46f0e12422f2d810dd782e2530613b":[6,0,2,11,349,1],
+"d3/d97/classisc_1_1dhcp_1_1TokenVendorClass.html#a2b46f0e12422f2d810dd782e2530613b":[7,0,1,9,349,1],
 "d3/d97/classisc_1_1dhcp_1_1TokenVendorClass.html#ae2467592df0afcbcb6ef287e7473e2da":[6,0,2,11,349,4],
 "d3/d97/classisc_1_1dhcp_1_1TokenVendorClass.html#ae2467592df0afcbcb6ef287e7473e2da":[7,0,1,9,349,4],
 "d3/d97/classisc_1_1dhcp_1_1TokenVendorClass.html#af3b2c47c6ac4e684672116adc8efaa4f":[7,0,1,9,349,2],
 "d3/d97/classisc_1_1dhcp_1_1TokenVendorClass.html#af3b2c47c6ac4e684672116adc8efaa4f":[6,0,2,11,349,2],
 "d3/d98/classisc_1_1dns_1_1rdata_1_1generic_1_1NS.html":[7,0,1,11,1,2,14],
 "d3/d98/classisc_1_1dns_1_1rdata_1_1generic_1_1NS.html":[6,0,2,13,2,2,14],
-"d3/d98/classisc_1_1dns_1_1rdata_1_1generic_1_1NS.html#a074ecb9c3b7d3de5268f3ac510d4c748":[6,0,2,13,2,2,14,7],
 "d3/d98/classisc_1_1dns_1_1rdata_1_1generic_1_1NS.html#a074ecb9c3b7d3de5268f3ac510d4c748":[7,0,1,11,1,2,14,7],
+"d3/d98/classisc_1_1dns_1_1rdata_1_1generic_1_1NS.html#a074ecb9c3b7d3de5268f3ac510d4c748":[6,0,2,13,2,2,14,7],
 "d3/d98/classisc_1_1dns_1_1rdata_1_1generic_1_1NS.html#a0cd5b91476f2930e2c72bc35d355316d":[6,0,2,13,2,2,14,3],
 "d3/d98/classisc_1_1dns_1_1rdata_1_1generic_1_1NS.html#a0cd5b91476f2930e2c72bc35d355316d":[7,0,1,11,1,2,14,3],
-"d3/d98/classisc_1_1dns_1_1rdata_1_1generic_1_1NS.html#a2ce0a96c8b8a86ebec51507db40d85ba":[7,0,1,11,1,2,14,9],
 "d3/d98/classisc_1_1dns_1_1rdata_1_1generic_1_1NS.html#a2ce0a96c8b8a86ebec51507db40d85ba":[6,0,2,13,2,2,14,9],
+"d3/d98/classisc_1_1dns_1_1rdata_1_1generic_1_1NS.html#a2ce0a96c8b8a86ebec51507db40d85ba":[7,0,1,11,1,2,14,9],
 "d3/d98/classisc_1_1dns_1_1rdata_1_1generic_1_1NS.html#a317ff279307ae3c34264b371531d0a88":[6,0,2,13,2,2,14,1],
 "d3/d98/classisc_1_1dns_1_1rdata_1_1generic_1_1NS.html#a317ff279307ae3c34264b371531d0a88":[7,0,1,11,1,2,14,1],
 "d3/d98/classisc_1_1dns_1_1rdata_1_1generic_1_1NS.html#a688db3c2d892602c4ca1ef7d4954b7d6":[6,0,2,13,2,2,14,5],
 "d3/d98/classisc_1_1dns_1_1rdata_1_1generic_1_1NS.html#a688db3c2d892602c4ca1ef7d4954b7d6":[7,0,1,11,1,2,14,5],
-"d3/d98/classisc_1_1dns_1_1rdata_1_1generic_1_1NS.html#a6b93da1023fc53348ca07ea4cff18e2f":[6,0,2,13,2,2,14,0],
 "d3/d98/classisc_1_1dns_1_1rdata_1_1generic_1_1NS.html#a6b93da1023fc53348ca07ea4cff18e2f":[7,0,1,11,1,2,14,0],
-"d3/d98/classisc_1_1dns_1_1rdata_1_1generic_1_1NS.html#a756879e0b8a91150f7198f96dbcc3d81":[7,0,1,11,1,2,14,2],
+"d3/d98/classisc_1_1dns_1_1rdata_1_1generic_1_1NS.html#a6b93da1023fc53348ca07ea4cff18e2f":[6,0,2,13,2,2,14,0],
 "d3/d98/classisc_1_1dns_1_1rdata_1_1generic_1_1NS.html#a756879e0b8a91150f7198f96dbcc3d81":[6,0,2,13,2,2,14,2],
-"d3/d98/classisc_1_1dns_1_1rdata_1_1generic_1_1NS.html#a8876d1d9489c0e3679eb8719cd8a3866":[7,0,1,11,1,2,14,8],
-"d3/d98/classisc_1_1dns_1_1rdata_1_1generic_1_1NS.html#a8876d1d9489c0e3679eb8719cd8a3866":[6,0,2,13,2,2,14,8],
-"d3/d98/classisc_1_1dns_1_1rdata_1_1generic_1_1NS.html#a8bf4a0ac86c3e8fa6502952571993fbd":[7,0,1,11,1,2,14,6],
-"d3/d98/classisc_1_1dns_1_1rdata_1_1generic_1_1NS.html#a8bf4a0ac86c3e8fa6502952571993fbd":[6,0,2,13,2,2,14,6],
-"d3/d98/classisc_1_1dns_1_1rdata_1_1generic_1_1NS.html#acc36f7d1cca8a95985240391c52f3640":[7,0,1,11,1,2,14,4],
-"d3/d98/classisc_1_1dns_1_1rdata_1_1generic_1_1NS.html#acc36f7d1cca8a95985240391c52f3640":[6,0,2,13,2,2,14,4],
-"d3/d99/classisc_1_1http_1_1HttpTimeConversionError.html":[7,0,1,16,38],
-"d3/d99/classisc_1_1http_1_1HttpTimeConversionError.html":[6,0,2,18,38],
-"d3/d99/classisc_1_1http_1_1HttpTimeConversionError.html#a1432e75a05700b999c58ea08be960fc5":[7,0,1,16,38,0],
-"d3/d99/classisc_1_1http_1_1HttpTimeConversionError.html#a1432e75a05700b999c58ea08be960fc5":[6,0,2,18,38,0],
-"d3/d9b/eval__messages_8h.html":[8,0,0,2,13,8],
-"d3/d9b/eval__messages_8h_source.html":[8,0,0,2,13,8],
-"d3/d9c/classisc_1_1dhcp_1_1PktFilterLPF.html":[6,0,2,11,254],
-"d3/d9c/classisc_1_1dhcp_1_1PktFilterLPF.html":[7,0,1,9,254],
-"d3/d9c/classisc_1_1dhcp_1_1PktFilterLPF.html#a0883ad360070634beebdfebbed52d45a":[6,0,2,11,254,0],
-"d3/d9c/classisc_1_1dhcp_1_1PktFilterLPF.html#a0883ad360070634beebdfebbed52d45a":[7,0,1,9,254,0],
-"d3/d9c/classisc_1_1dhcp_1_1PktFilterLPF.html#a872d780eec1387f7f4f4029b2cb0adcf":[7,0,1,9,254,3],
-"d3/d9c/classisc_1_1dhcp_1_1PktFilterLPF.html#a872d780eec1387f7f4f4029b2cb0adcf":[6,0,2,11,254,3],
-"d3/d9c/classisc_1_1dhcp_1_1PktFilterLPF.html#ab579445e7339c0753b057b0fbdb1de53":[7,0,1,9,254,1],
-"d3/d9c/classisc_1_1dhcp_1_1PktFilterLPF.html#ab579445e7339c0753b057b0fbdb1de53":[6,0,2,11,254,1],
-"d3/d9c/classisc_1_1dhcp_1_1PktFilterLPF.html#af5c97e6fcd61512709a3feb16ddbc830":[7,0,1,9,254,2],
-"d3/d9c/classisc_1_1dhcp_1_1PktFilterLPF.html#af5c97e6fcd61512709a3feb16ddbc830":[6,0,2,11,254,2],
-"d3/d9f/redact__config_8cc.html":[8,0,0,2,20,22],
-"d3/d9f/redact__config_8cc.html#ade84b00304532d7d55dde7da0370ac6a":[8,0,0,2,20,22,0],
-"d3/d9f/redact__config_8cc_source.html":[8,0,0,2,20,22],
-"d3/d9f/structisc_1_1dhcp_1_1OptionDataTypeTraits_3_01OptionBuffer_01_4.html":[6,0,2,11,199],
-"d3/d9f/structisc_1_1dhcp_1_1OptionDataTypeTraits_3_01OptionBuffer_01_4.html":[7,0,1,9,199],
-"d3/da2/translator_8cc.html":[8,0,0,2,24,13],
-"d3/da2/translator_8cc_source.html":[8,0,0,2,24,13],
-"d3/da7/host__data__source__factory_8cc.html":[8,0,0,2,11,92],
-"d3/da7/host__data__source__factory_8cc_source.html":[8,0,0,2,11,92],
-"d3/da7/namespaceisc_1_1util_1_1encode.html":[6,0,2,28,1],
-"d3/da7/namespaceisc_1_1util_1_1encode.html#a167c9ece654bbd53ba169e5cb9f4c725":[6,0,2,28,1,2],
-"d3/da7/namespaceisc_1_1util_1_1encode.html#a2a5062a8bb0a3df37498ad248fab7cee":[6,0,2,28,1,5],
-"d3/da7/namespaceisc_1_1util_1_1encode.html#a351eb234219d50d8ef02d2a1907d267f":[6,0,2,28,1,7],
-"d3/da7/namespaceisc_1_1util_1_1encode.html#a40415239f4efe0ca4dbde60fa0c27fa9":[6,0,2,28,1,6],
-"d3/da7/namespaceisc_1_1util_1_1encode.html#a6721d96e64201a02414163825344e634":[6,0,2,28,1,1],
-"d3/da7/namespaceisc_1_1util_1_1encode.html#a6f960fd8e86c16a6419701bdc23e3c43":[6,0,2,28,1,3],
-"d3/da7/namespaceisc_1_1util_1_1encode.html#ad3fe40bfd4eec882db7079194dba45ee":[6,0,2,28,1,4],
-"d3/da7/namespaceisc_1_1util_1_1encode.html#ad6c153a1200b8b6223d11f4e7d0ceae7":[6,0,2,28,1,8],
-"d3/dab/db__exceptions_8h.html":[8,0,0,2,8,6],
-"d3/dab/db__exceptions_8h_source.html":[8,0,0,2,8,6],
-"d3/dab/observation_8h.html":[8,0,0,2,21,3],
-"d3/dab/observation_8h.html#a628dfd5ba6148fe428852217f183e483":[8,0,0,2,21,3,5],
-"d3/dab/observation_8h.html#a6caf14e77d993146f5dc4b9e755942f5":[8,0,0,2,21,3,6],
-"d3/dab/observation_8h.html#ab1440d7d4f5dc058ddd63552f6baabeb":[8,0,0,2,21,3,9],
-"d3/dab/observation_8h.html#adab8a849f86284157fd876647f8e8365":[8,0,0,2,21,3,7],
-"d3/dab/observation_8h_source.html":[8,0,0,2,21,3],
-"d3/dac/pid__file_8cc.html":[8,0,0,2,23,27],
-"d3/dac/pid__file_8cc_source.html":[8,0,0,2,23,27],
-"d3/dad/classisc_1_1dns_1_1rdata_1_1RdataPimplHolder.html":[7,0,1,11,1,11],
-"d3/dad/classisc_1_1dns_1_1rdata_1_1RdataPimplHolder.html":[6,0,2,13,2,11],
-"d3/dad/classisc_1_1dns_1_1rdata_1_1RdataPimplHolder.html#a2189d4f971c4da3336665afc08f259f5":[6,0,2,13,2,11,4],
-"d3/dad/classisc_1_1dns_1_1rdata_1_1RdataPimplHolder.html#a2189d4f971c4da3336665afc08f259f5":[7,0,1,11,1,11,4],
-"d3/dad/classisc_1_1dns_1_1rdata_1_1RdataPimplHolder.html#a3f7bced6d6f2e83e3524733c13091dbf":[7,0,1,11,1,11,1],
-"d3/dad/classisc_1_1dns_1_1rdata_1_1RdataPimplHolder.html#a3f7bced6d6f2e83e3524733c13091dbf":[6,0,2,13,2,11,1],
-"d3/dad/classisc_1_1dns_1_1rdata_1_1RdataPimplHolder.html#a717a7a9b3016fef033de07b6fa326101":[7,0,1,11,1,11,3],
-"d3/dad/classisc_1_1dns_1_1rdata_1_1RdataPimplHolder.html#a717a7a9b3016fef033de07b6fa326101":[6,0,2,13,2,11,3],
-"d3/dad/classisc_1_1dns_1_1rdata_1_1RdataPimplHolder.html#acf200021cee26564b85dd01ae680f806":[7,0,1,11,1,11,0],
-"d3/dad/classisc_1_1dns_1_1rdata_1_1RdataPimplHolder.html#acf200021cee26564b85dd01ae680f806":[6,0,2,13,2,11,0],
-"d3/dad/classisc_1_1dns_1_1rdata_1_1RdataPimplHolder.html#ae609c952eb4dc2c03080250061c3f874":[6,0,2,13,2,11,2],
-"d3/dad/classisc_1_1dns_1_1rdata_1_1RdataPimplHolder.html#ae609c952eb4dc2c03080250061c3f874":[7,0,1,11,1,11,2],
-"d3/dad/hooks__messages_8h.html":[8,0,0,2,15,14],
-"d3/dad/hooks__messages_8h_source.html":[8,0,0,2,15,14],
-"d3/dad/structisc_1_1db_1_1MySqlBindingTraits.html":[6,0,2,9,28],
-"d3/dad/structisc_1_1db_1_1MySqlBindingTraits.html":[7,0,1,8,28],
-"d3/dae/client__connection_8cc.html":[8,0,0,2,4,2],
-"d3/dae/client__connection_8cc_source.html":[8,0,0,2,4,2],
-"d3/db0/command__interpreter_8h.html":[8,0,0,2,2,4],
-"d3/db0/command__interpreter_8h.html#a10d10150db0055c0464577cbce6d68fc":[8,0,0,2,2,4,1],
-"d3/db0/command__interpreter_8h.html#a1cb0a2aaf022f20adbf8001e82a14ca6":[8,0,0,2,2,4,6],
-"d3/db0/command__interpreter_8h.html#a278ca7e9bb1342e075e11a407c7e5522":[8,0,0,2,2,4,10],
-"d3/db0/command__interpreter_8h.html#a29588c6bed3559f3705f9c89d8bee041":[8,0,0,2,2,4,15],
-"d3/db0/command__interpreter_8h.html#a2e7f3d2839861d7b7779bd6bf1d7f4dc":[8,0,0,2,2,4,11],
-"d3/db0/command__interpreter_8h.html#a3333ddd4036c231272306261abe51349":[8,0,0,2,2,4,7],
-"d3/db0/command__interpreter_8h.html#a34724db07410521d6247c90a7e5af465":[8,0,0,2,2,4,16],
-"d3/db0/command__interpreter_8h.html#a54a193e7103a5c51ba73131ecea6efc7":[8,0,0,2,2,4,2],
-"d3/db0/command__interpreter_8h.html#a572a8f0733ca50d4e2946081518b0355":[8,0,0,2,2,4,8],
-"d3/db0/command__interpreter_8h.html#a6670f14c040170310a549a5cb15bafef":[8,0,0,2,2,4,12],
-"d3/db0/command__interpreter_8h.html#a797e824bd280a05c20920d8b1fe3e144":[8,0,0,2,2,4,9],
-"d3/db0/command__interpreter_8h.html#a874ab2103762d8775d65b7f0fddb5159":[8,0,0,2,2,4,13],
-"d3/db0/command__interpreter_8h.html#a8e9fbb78d645acf8ddd582189a3c176e":[8,0,0,2,2,4,5],
-"d3/db0/command__interpreter_8h.html#a95f20812f57e424165977df3128bc7f7":[8,0,0,2,2,4,3]
+"d3/d98/classisc_1_1dns_1_1rdata_1_1generic_1_1NS.html#a756879e0b8a91150f7198f96dbcc3d81":[7,0,1,11,1,2,14,2],
+"d3/d98/classisc_1_1dns_1_1rdata_1_1generic_1_1NS.html#a8876d1d9489c0e3679eb8719cd8a3866":[7,0,1,11,1,2,14,8]
 };
